% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_sets.R
\name{utils_sets}
\alias{utils_sets}
\alias{set_intersect}
\alias{set_union}
\alias{set_difference}
\title{Utilities for set operations for many sets}
\usage{
set_intersect(..., pairs = FALSE)

set_union(..., pairs = FALSE)

set_difference(..., pairs = FALSE)
}
\arguments{
\item{...}{A list or a comma-separated list of vectors in the same class. If
vector contains duplicates they will be discarded. If the list doesn't have
names the sets will be named as \code{"set_1"}, "\verb{Set_2"}, \code{"Set_3"} and so on.
If vectors are given in \code{...}, the set names will be named with the names
of the objects provided. Data frames are also allowed, provided that common
column names exist.}

\item{pairs}{Returns the pairwise unions of the sets? Defaults to \code{FALSE}.}
}
\value{
A vector showing the desired operation of the sets. If \code{pairs = TRUE}, returns a list showing the pairwise operation of the sets.
}
\description{
\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#stable}{\figure{lifecycle-stable.svg}{options: alt='[Stable]'}}}{\strong{[Stable]}}

Provides alternative function to \code{\link[base:sets]{base::union()}}, \code{\link[base:sets]{base::intersect()}}, and
\code{\link[base:sets]{base::setdiff()}}.
\itemize{
\item \code{set_union()}: Returns the union of the sets in \code{...}.
\item \code{set_intersect()}: Returns the intersect of the sets in \code{...}.
\item \code{set_difference()}: Returns the difference of the sets in \code{...}.
}
}
\examples{
\donttest{
library(metan)
(A <- letters[1:4])
(B <- letters[2:5])
(C <- letters[3:7])

set_union(A, B)
set_intersect(A, B, C)
set_difference(B, C)

# Operations with data frames
# Add a row id for better understanding
sets <- data_ge \%>\% add_row_id()

set_1 <- sets[1:5,]
set_2 <- sets[2:6,]
set_3 <- sets[3:7,]

set_intersect(set_1, set_2, set_3)
set_difference(set_2, set_3)
set_union(set_1, set_2, set_3)
}

}
\author{
Tiago Olivoto \email{tiagoolivoto@gmail.com}
}
